@@ -1,9 +1,9 @@
 package Sah::Schemas::Chrome;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-19'; # DATE
+our $DATE = '2021-07-19'; # DATE
 our $DIST = 'Sah-Schemas-Chrome'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas related to Google Chrome
@@ -20,7 +20,23 @@ Sah::Schemas::Chrome - Various Sah schemas related to Google Chrome
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::Chrome (from Perl distribution Sah-Schemas-Chrome), released on 2020-04-19.
+This document describes version 0.002 of Sah::Schemas::Chrome (from Perl distribution Sah-Schemas-Chrome), released on 2021-07-19.
+
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on pc-home)
+
+perlancar (on pc-home) <perlancar@gmail.com>
+
+=head1 SAH SCHEMAS
+
+=over
+
+=item * L<chrome::profile_name|Sah::Schema::chrome::profile_name>
+
+Chrome profile name.
+
+=back
 
 =head1 HOMEPAGE
 
@@ -50,7 +66,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
